==> libreoffice-fresh-sdk-7.5.0-1-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/variables_9.js <==
var searchData=
[
  ['j_0',['J',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html#aa6010a052250e93302264bdd36271d88',1,'com::sun::star::awt::Key']]],
  ['january_1',['JANUARY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#a5cf0296928101ce2b8d17bebb5e73c90',1,'com::sun::star::i18n::Months']]],
  ['japanese_2',['Japanese',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CandleStickChartType.html#a2cad0926393f307b8b4962ffde9bbee4',1,'com::sun::star::chart2::CandleStickChartType']]],
  ['java_3',['JAVA',['../namespacecom_1_1sun_1_1star_1_1bridge_1_1ModelDependent.html#a135a03e8044b16fb22bc1c7633e7c658',1,'com::sun::star::bridge::ModelDependent']]],
  ['javadriverclass_4',['JavaDriverClass',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#abdc08b85c582f65f578e62cd9e747bad',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['javadriverclasspath_5',['JavaDriverClassPath',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#afa6ea96eef4856627c8fef22aaa92d22',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['jobname_6',['JobName',['../servicecom_1_1sun_1_1star_1_1view_1_1PrintOptions.html#a896deaa5ee4ac22bd1c8b5b8db37acf1',1,'com::sun::star::view::PrintOptions']]],
  ['jointype_7',['JoinType',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html#af92b960dfbc8558928096e5b2076117c',1,'com::sun::star::rendering::StrokeAttributes']]],
  ['journal_8',['JOURNAL',['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataField::JOURNAL()'],['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataType::JOURNAL()']]],
  ['july_9',['JULY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#aae7c7cc5b45c941aade847449d8355a2',1,'com::sun::star::i18n::Months']]],
  ['jumpmark_10',['JumpMark',['../servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html#a51b2490ba24ae76328c7637f379d8a69',1,'com::sun::star::document::MediaDescriptor']]],
  ['june_11',['JUNE',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#af314dbaf560683281ea205a8e8726e7e',1,'com::sun::star::i18n::Months']]]
];

==> libreoffice-fresh-sdk-7.6.4-2-aarch64.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/variables_9.js <==
var searchData=
[
  ['j_0',['J',['../namespacecom_1_1sun_1_1star_1_1awt_1_1Key.html#aa6010a052250e93302264bdd36271d88',1,'com::sun::star::awt::Key']]],
  ['january_1',['JANUARY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#a5cf0296928101ce2b8d17bebb5e73c90',1,'com::sun::star::i18n::Months']]],
  ['japanese_2',['Japanese',['../servicecom_1_1sun_1_1star_1_1chart2_1_1CandleStickChartType.html#a2cad0926393f307b8b4962ffde9bbee4',1,'com::sun::star::chart2::CandleStickChartType']]],
  ['java_3',['JAVA',['../namespacecom_1_1sun_1_1star_1_1bridge_1_1ModelDependent.html#a135a03e8044b16fb22bc1c7633e7c658',1,'com::sun::star::bridge::ModelDependent']]],
  ['javadriverclass_4',['JavaDriverClass',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#abdc08b85c582f65f578e62cd9e747bad',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['javadriverclasspath_5',['JavaDriverClassPath',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1JDBCConnectionProperties.html#afa6ea96eef4856627c8fef22aaa92d22',1,'com::sun::star::sdbc::JDBCConnectionProperties']]],
  ['jobname_6',['JobName',['../servicecom_1_1sun_1_1star_1_1view_1_1PrintOptions.html#a896deaa5ee4ac22bd1c8b5b8db37acf1',1,'com::sun::star::view::PrintOptions']]],
  ['jointype_7',['JoinType',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html#af92b960dfbc8558928096e5b2076117c',1,'com::sun::star::rendering::StrokeAttributes']]],
  ['journal_8',['journal',['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataField::JOURNAL'],['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataType::JOURNAL']]],
  ['july_9',['JULY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#aae7c7cc5b45c941aade847449d8355a2',1,'com::sun::star::i18n::Months']]],
  ['jumpmark_10',['JumpMark',['../servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html#a51b2490ba24ae76328c7637f379d8a69',1,'com::sun::star::document::MediaDescriptor']]],
  ['june_11',['JUNE',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#af314dbaf560683281ea205a8e8726e7e',1,'com::sun::star::i18n::Months']]]
];
